# Your Autograding Deputy (YAD)

Visit the GitHub for all your needs: https://github.com/AutoGradingDeputy/YAD

If you are looking for the user manual you can find it here: https://autogradingdeputy.github.io/YAD/